package com.lizlam.hayward_gems;

import com.google.gson.JsonArray;
import com.google.gson.JsonElement;
import com.google.gson.JsonObject;
import com.google.gson.JsonParser;

import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.net.HttpURLConnection;
import java.net.URL;
import java.util.Calendar;
import java.util.Date;
import java.util.Locale;

/**
 * Created by liz on 5/11/15.
 */
public class MeetUpAPI {

    final static String API_KEY = "meetup api key goes here";
    final static String REQUEST_URL = "https://api.meetup.com/2/events?&signed=true&photo-host=public&group_urlname=Hayward-Techies&page=20";
    static final String GROUP_WEBSITE = "http://www.meetup.com/Hayward-Techies/";


    public static MeetUp getUpcomingMeetup() {
        String info = getData(REQUEST_URL + "&key=" + API_KEY);
        JsonObject jsonResult = new JsonParser().parse(info).getAsJsonObject();
        JsonArray resultsArray = jsonResult.getAsJsonArray("results");

        JsonObject venue = (JsonObject) resultsArray.get(0).getAsJsonObject().get("venue");
        String description = resultsArray.get(0).getAsJsonObject().get("description").toString();
        Long unixtime = resultsArray.get(0).getAsJsonObject().get("time").getAsLong();
        String nextMeetingDate = getDate(unixtime);
        String time = getTime(unixtime);

        MeetUp meetUp = new MeetUp();
        meetUp.setLocName(removeQuotes(venue.get("name").toString()));
        meetUp.setAddress(removeQuotes(venue.get("address_1").toString()) + ", " + removeQuotes(venue.get("city").toString()));
        meetUp.setDescription(description);
        meetUp.setLat(venue.get("lat").getAsDouble());
        meetUp.setLng(venue.get("lon").getAsDouble());
        meetUp.setWebsite(GROUP_WEBSITE);
        meetUp.setNextMeetingDate(nextMeetingDate);
        meetUp.setNextMeetingTime(time);
        System.out.println(info);
        return meetUp;
    }

    public static String removeQuotes(String addr) {
        String address;
        address = addr.substring(1, addr.length()-1);
        return address;
    }

    public static String getData(String uri) {

        BufferedReader reader = null;

        try {
            URL url = new URL(uri);
            HttpURLConnection con = (HttpURLConnection) url.openConnection();

            StringBuilder sb = new StringBuilder();
            reader = new BufferedReader(new InputStreamReader(con.getInputStream()));

            String line;
            while ((line = reader.readLine()) != null) {
                sb.append(line + "\n");
            }
            return sb.toString();
        } catch (Exception e) {
            e.printStackTrace();
            return null;
        } finally {
            if (reader != null) {
                try {
                    reader.close();
                } catch (Exception e) {
                    e.printStackTrace();
                    return null;
                }
            }
        }
    }

    public static String getDate(Long unixtime) {
        StringBuilder date = new StringBuilder();
        int format = Calendar.SHORT;
        Locale locale = Locale.US;

        Calendar cal = Calendar.getInstance();
        cal.setTimeInMillis(unixtime);
        date.append(cal.getDisplayName(Calendar.DAY_OF_WEEK, format, locale) + " ");
        date.append(cal.getDisplayName(Calendar.MONTH, format, locale) + " ");
        date.append(cal.get(Calendar.DAY_OF_MONTH) + " ");
        date.append(cal.get(Calendar.YEAR) + "\n");

        return date.toString();
    }

    public static String getTime(Long unixtime) {
        StringBuilder sb = new StringBuilder();
        Calendar cal = Calendar.getInstance();
        cal.setTimeInMillis(unixtime);
        sb.append(cal.get(Calendar.HOUR));
        if (cal.get(Calendar.MINUTE) != 0) {
            sb.append(":" + cal.get(Calendar.MINUTE) + " ");
        }
        sb.append(cal.getDisplayName(Calendar.AM_PM, Calendar.LONG, Locale.US));

        return sb.toString();
    }

    public static void main(String[] args) {
        System.out.println("Testing meetup API");
        MeetUpAPI.getUpcomingMeetup();
    }
}
